/*------------------------------------------------------------------
[Master Scripts]

Project:    Narrative theme
Version:    1.1.2

[Table of contents]

[Components]

	-Preloader 
	-Equal Height function 
	-Project slider 
	-Search 
	-Navigation 
	-Side bar 
	-Banner category 
	-Banner about 
	-Mobile menu 
	-Fixed header 
	-Price list 
	-Screen rezise events 
	-Project horizontal slider 
	-Scroll top button 
	-Fix centered container 
	-Portfolio items & filtering 
	-Blog items & filtering 
	-Post gallery masonry 
	-Comment reply 
	-Parallax 
	-Quantity 
	-Skills animation 
	
-------------------------------------------------------------------*/

"use strict";

/*------------------------------------------------------------------
[ Preloader ]
*/
jQuery(window).on('load', function () {
    jQuery(window).trigger('resize').trigger('scroll');
    var $preloader = jQuery('.preloader'),
        $spinner   = $preloader.find('.spinner');
    $spinner.fadeOut();
    $preloader.delay(350).fadeOut('slow');

    jQuery('.owl-carousel').each(function(){
		jQuery(this).trigger('refresh.owl.carousel');
	});

    if(typeof skrollr !== "undefined") {
		skrollr.get().refresh();
	}
});

jQuery('.tabs').each(function(){
	var item = jQuery(this).find('.item'),
		tabs_head = jQuery(this).find('.tabs-head');
	item.each(function() {
		var name = jQuery(this).data('name');
		tabs_head.append('<div class="item">'+name+'</div>');
	});
	tabs_head.find('.item:first-of-type').addClass('active-tab');
	jQuery(this).find('.tabs-body .item:first-of-type').css('display', 'block');
});

jQuery('.tabs-head').on('click', '.item:not(.active-tab)', function() {  
	jQuery(this).addClass('active-tab').siblings().removeClass('active-tab').parents('.tabs').find('.tabs-body .item').eq(jQuery(this).index()).fadeIn(150).siblings().hide();  
});

jQuery(document).ready(function() {

	/*------------------------------------------------------------------
	[ Equal Height function ]
	*/
	function equalHeight(group) {
        if(jQuery(window).width() > '768') {
			var tallest = 0;
	       	jQuery(group).each(function() {
	            var thisHeight = jQuery(this).height('auto').height();
	            if(thisHeight > tallest) {
	                tallest = thisHeight;
	            }
	        });
	        jQuery(group).height(tallest);
	    } else {
	    	jQuery(group).height('auto');
	    }
    }

    if(jQuery('.navigation > ul > li').length > 6) {
		jQuery('.navigation').addClass('min');
	}

	/*------------------------------------------------------------------
	[ Project slider ]
	*/
	jQuery('.project-slider').each(function(){
		var head_slider = jQuery(this);
		if(head_slider.find('.item').length == 1) {
			head_slider.parent().removeClass('with-carousel-nav');
		}
		if(jQuery(this).find('.item').length > 1){
			head_slider.addClass('owl-carousel').owlCarousel({
				//loop:true,
				items:1,
				nav: false,
				dots: true,
				autoplay: false,
				navText: false,
				responsive:{
					0:{
						nav: false,
					},
					480:{

					},
					768:{
						nav: true,
					},
				},
			});
		}
	});

    /*------------------------------------------------------------------
	[ Search ]
	*/

	jQuery('.site-header .search-button').on("click", function(){
		if(jQuery(this).hasClass('active')) {
			jQuery(this).removeClass('active');
			jQuery('.search-popup').fadeOut();
		} else {
			jQuery(this).addClass('active');
			jQuery('.search-popup').fadeIn();
		}
	});

	jQuery('.search-popup .close').on("click", function(){
		jQuery('.site-header .search-button').removeClass('active');
		jQuery('.search-popup').fadeOut();
	});
	
	/*------------------------------------------------------------------
	[ Open portfolio ]
	*/

	jQuery('.portfolio-item .pi-bottom .b, .portfolio-item .p-content .close').on("click", function(){
		if(jQuery(this).parents('.portfolio-item').hasClass('active')) {
			jQuery(this).parents('.portfolio-item').removeClass('active');
		} else {
			jQuery(this).parents('.portfolio-item').addClass('active');
		}
		return false;
	});

	jQuery('.portfolio-slider .item .button').on("click", function(){
		jQuery(this).parents('.item').find('.p-content').addClass('active');
		return false;
	});

	jQuery('.portfolio-slider .item .p-content .close').on("click", function(){
		jQuery(this).parents('.p-content').removeClass('active');
		return false;
	});
	
	/*------------------------------------------------------------------
	[ Navigation ]
	*/

	jQuery('.nav-button.hidden_menu, .nav-button.visible_menu').on('click', function() {
		if(jQuery(this).hasClass('active')) {
			jQuery(this).removeClass('active');
			jQuery('.navigation').removeClass('active');
		} else {
			jQuery(this).addClass('active');
			jQuery('.navigation').addClass('active');
		}
		jQuery('.site-header').toggleClass('header-nav');
	});

	jQuery('.nav-button.full_screen').on('click', function() {
		if(jQuery(this).hasClass('active')) {
			jQuery(this).removeClass('active');
			jQuery('.full-screen-nav').fadeOut();
		} else {
			jQuery(this).addClass('active');
			jQuery('.full-screen-nav').fadeIn();
		}
	});

	jQuery('.full-screen-nav .close').on("click", function(){
		jQuery('.nav-button.full_screen').removeClass('active');
		jQuery('.full-screen-nav').fadeOut();
	});

	jQuery('.full-screen-nav .menu-item-has-children > a').on("click", function(){
		if(!jQuery(this).hasClass('active')) {
			jQuery(this).addClass('active').parent().children('.sub-menu').slideDown().parent().siblings().children('a').removeClass('active').next('.sub-menu').slideUp();
			return false;
		}
	});

	jQuery('.side-navigation ul li.menu-item-has-children > a,.side-navigation ul li.page_item_has_children > a').on('click', function(){
		jQuery(this).parents('li').addClass('active-child');
		return false;
	});

	jQuery('.side-navigation .sub-menu .back,.side-navigation .children .back').on('click', function(){
		jQuery(this).parent().parent().removeClass('active-child');
		return false;
	});
	
	/*------------------------------------------------------------------
	[ Accordion ]
	*/

	jQuery('.accordion-items .item .top').on('click', function() {
		if(jQuery(this).parent().hasClass('active')) {
			jQuery(this).parent().removeClass('active').find('.wrap').slideUp();
		} else {
			jQuery(this).parent().addClass('active').find('.wrap').slideDown();
		}
	});
	
	/*------------------------------------------------------------------
	[ Side bar ]
	*/

	jQuery('.open-side-bar').on('click', function() {
		if(jQuery(this).hasClass('active')) {
			jQuery(this).removeClass('active');
			jQuery('.side-bar-area').removeClass('active');
		} else {
			jQuery(this).addClass('active');
			jQuery('.side-bar-area').addClass('active');
		}
	});

	jQuery('.side-bar-area .close').on("click", function(){
		jQuery('.side-bar-area,.open-side-bar').removeClass('active');
	});
	
	/*------------------------------------------------------------------
	[ Banner category ]
	*/

	jQuery('.banner-button-right .about').on('click', function() {
		if(jQuery(this).hasClass('active')) {
			jQuery(this).removeClass('active').parents('.banner-area').find('.banner-about').removeClass('active');
		} else {
			jQuery(this).addClass('active').parents('.banner-area').find('.banner-about').addClass('active');
			jQuery(this).parents('.banner-area').find('.banner-contacts').removeClass('active');
			jQuery('.banner-button-left .contact').removeClass('active');
		}
	});
	
	/*------------------------------------------------------------------
	[ Banner about ]
	*/

	jQuery('.banner-button-left .contact').on('click', function() {
		if(jQuery(this).hasClass('active')) {
			jQuery(this).removeClass('active').parents('.banner-area').find('.banner-contacts').removeClass('active');
		} else {
			jQuery(this).addClass('active').parents('.banner-area').find('.banner-contacts').addClass('active');
			jQuery(this).parents('.banner-area').find('.banner-about').removeClass('active');
			jQuery('.banner-button-right .about').removeClass('active');
		}
	});
	
	/*------------------------------------------------------------------
	[ Mobile menu ]
	*/
	
	jQuery(window).on("load resize", function(){
		if(jQuery(window).width() <= '1200') {
			jQuery('.navigation .menu-item-has-children > a').on("click", function(){
				if(!jQuery(this).hasClass('active')) {
					jQuery(this).addClass('active').parent().children('.sub-menu').slideDown().siblings().children('.sub-menu').slideUp();
					return false;
				}
			});
		}
	});

	/*------------------------------------------------------------------
	[ Fixed header ]
	*/

	jQuery(window).on("load resize scroll", function(){
		if ( jQuery(document).scrollTop() > 0 ) {
			jQuery('.site-header').addClass('fixed');
		} else {
			jQuery('.site-header').removeClass('fixed');
		}

		jQuery('.project-slider').each(function() {
			if(parseInt(jQuery(window).scrollTop()+jQuery(window).height()) > parseInt(jQuery(document).height()-jQuery('.site-footer').outerHeight())) {
				jQuery('.project-slider').addClass('fixed').css('bottom', parseInt(jQuery(window).scrollTop()+jQuery(window).height()-jQuery('.site-footer').offset().top));
			} else {
				jQuery('.project-slider').removeClass('fixed').css('bottom', 0);
			}
			jQuery('.project-slider').find('.item').css('height', jQuery('.project-slider').height());
		});
	});

	/*------------------------------------------------------------------
	[ Price list ]
	*/

	jQuery(document).on('click', ".price-list .item .options .option-button", function(){
		if(jQuery(this).parent().hasClass('active')) {
			jQuery(this).removeClass('active').parent().removeClass('active').find('.wrap').slideUp('800');
			jQuery(this).parents('.item').removeClass('active');
		} else {
			jQuery(this).addClass('active').parent().addClass('active').find('.wrap').slideDown('800');
			jQuery(this).parents('.item').addClass('active');
		}
		return false;
	});

	/*------------------------------------------------------------------
	[ Portfolio split screen ]
	*/

	jQuery('.portfolio-split-screen-wrap').each(function() {
		function leadZero(n) { return (n < 10 ? '0' : '') + n; }

		var this_el = jQuery(this),
			slider = this_el.find('.slider'),
			item = this_el.find('.item'),
			nav_html = '';

		if(item.length > 1) {
			nav_html = '<div class="portfolio-navigation">';
				nav_html += '<div class="numbers">';
					item.each(function() {
						nav_html += '<div class="num" data-index="'+(jQuery(this).index())+'">'+leadZero((jQuery(this).index()+1))+'</div>';
					});
				nav_html += '</div>';
				nav_html += '<div class="arrows">';
					nav_html += '<div class="next base-icons-arrow-point-to-top"></div>';
					nav_html += '<div class="prev base-icons-arrow-point-to-bottom"></div>';
				nav_html += '</div>';
			nav_html += '</div>';
			this_el.append(nav_html);
		}

		slider.each(function() {
			jQuery(this).addClass('owl-carousel').owlCarousel({
				loop:true,
				items:1,
				nav: false,
				dots: true,
				autoplay: true,
				autoplayTimeout: 5000,
				autoplayHoverPause: true,
				navText: false,
			});
		});

		jQuery(window).on('load', function () {
			this_el.find('.item:eq(0), .num:eq(0)').addClass('active');
		});

		this_el.on('click', '.num:not(.active)', function() {
			var el = jQuery(this),
				index = el.data('index');

			item.eq(index).addClass('active').siblings().removeClass('active');
			el.addClass('active').siblings().removeClass('active');
		});

		function split_prev() {
			var el = jQuery(this),
				index = this_el.find('.item.active').index(),
				num = this_el.find('.num'),
				count = item.length;

			if(index+1 == 1) {
				item.eq(count-1).addClass('active').siblings().removeClass('active');
				num.eq(count-1).addClass('active').siblings().removeClass('active');
			} else {
				item.eq(index-1).addClass('active').siblings().removeClass('active');
				num.eq(index-1).addClass('active').siblings().removeClass('active');
			}
		}

		function split_next() {
			var el = jQuery(this),
				index = this_el.find('.item.active').index(),
				num = this_el.find('.num'),
				count = item.length;

			if(index+1 == count) {
				item.eq(0).addClass('active').siblings().removeClass('active');
				num.eq(0).addClass('active').siblings().removeClass('active');
			} else {
				item.eq(index+1).addClass('active').siblings().removeClass('active');
				num.eq(index+1).addClass('active').siblings().removeClass('active');
			}
		}

		this_el.on('click', '.prev', function() {
			split_prev();
		});

		this_el.on('click', '.next', function() {
			split_next();
		});
	});

	/*------------------------------------------------------------------
	[ Screen rezise events ]
	*/
	
	jQuery('#wpadminbar').addClass('wpadminbar');
	var nav_el = '';
	if(jQuery('.navigation').hasClass('visible_menu')) {
		nav_el = 'yes';
	}
	jQuery(window).on("load resize", function(){
	    jQuery('.header-space').css('height', jQuery('.site-header').outerHeight()+jQuery('.header + .navigation').outerHeight()+jQuery('.ypromo-site-bar').outerHeight());

	    jQuery('main.main-row').css('min-height', jQuery(window).outerHeight()-jQuery('.site-footer').outerHeight()-jQuery('.footer-social-button').outerHeight()-jQuery('.header-space:not(.hide)').outerHeight()-jQuery('.ypromo-site-bar').outerHeight()-jQuery('#wpadminbar').outerHeight()-parseInt(jQuery('#all').css('padding-top'))-parseInt(jQuery('#all').css('padding-bottom')));

	    jQuery('.protected-post-form .cell').css('height', jQuery(window).outerHeight()-jQuery('.site-footer').outerHeight()-jQuery('.footer-social-button').outerHeight()-jQuery('.header-space:not(.hide)').outerHeight()-jQuery('.ypromo-site-bar').outerHeight()-jQuery('#wpadminbar').outerHeight()-parseInt(jQuery('#all').css('padding-top'))-parseInt(jQuery('#all').css('padding-bottom')));

		jQuery('.banner:not(.fixed-height)').each(function(){
			jQuery(this).css('height', jQuery(window).outerHeight()-jQuery('.header-space:not(.hide)').outerHeight()-jQuery('#wpadminbar').outerHeight());
			jQuery(this).find('.cell').css('height', jQuery(this).height());
		});
		jQuery('.banner.fixed-height').each(function(){
			jQuery(this).find('.cell').css('height', jQuery(this).height());
		});

		jQuery('.project-slider').each(function(){
			jQuery(this).find('.item').css('height', jQuery(this).height());
		});

		jQuery('.portfolio-slider-style1').each(function() {
			jQuery(this).css('height', jQuery(window).height()-jQuery('#wpadminbar').height()-jQuery('.header-space:not(.hide)').outerHeight());
			jQuery(this).find('.cell').css('height', jQuery(this).height());
			jQuery(this).find('.a-img').css('height', jQuery(this).height());
		});

		jQuery('.portfolio-slider-style2').each(function() {
			jQuery(this).css('height', jQuery(window).height()-jQuery('#wpadminbar').height()-jQuery('.header-space:not(.hide)').outerHeight());
			jQuery(this).find('.a-img').css('height', jQuery(this).height()-jQuery(this).find('.category-buttons').outerHeight(true)-parseInt(jQuery(this).find('.item').css('padding-bottom')));
		});

		jQuery('.portfolio-slider-style3').each(function() {
			jQuery(this).css('height', jQuery(window).height()-jQuery('#wpadminbar').height()-jQuery('.header-space:not(.hide)').outerHeight());
			jQuery(this).find('.a-img').css('height', jQuery(this).height()-70);
		});

		jQuery('.category-items').each(function() {
			jQuery(this).css('height', jQuery(window).height()-jQuery('#wpadminbar').height()-jQuery('.header-space:not(.hide)').outerHeight());
			jQuery(this).find('.item').css('height', jQuery(this).height());
		});

		jQuery('.horizontal-type1 .content').each(function() {
			jQuery(this).css('padding-bottom', parseInt(jQuery(this).find('.bottom').outerHeight(true)));
		});

		jQuery('.side-header .cell').css('height', jQuery('.side-header .wrap').height());

		jQuery('.portfolio-split-screen-wrap').each(function() {
			jQuery(this).css('height', jQuery(window).height()-jQuery('#wpadminbar').height()-jQuery('.header-space:not(.hide)').outerHeight());
			jQuery(this).find('.portfolio-split-screen, .portfolio-split-screen .slider-item, .portfolio-split-screen .img').css('height', jQuery(this).height());
			jQuery(this).find('.top-content .cell, .bottom-content .cell').css('height', jQuery(this).height()/2);
		});

		jQuery('.portfolio-slider-style2').each(function() {
			jQuery(this).find('.portfolio-slider .container').css('width', parseInt(jQuery(this).width()-260));
		});

		if (nav_el == "yes") {
			if(jQuery(window).width() >= 1200) {
				jQuery('.navigation').addClass('visible_menu');
				jQuery('.nav-button').addClass('hidden');
			} else {
				jQuery('.navigation').removeClass('visible_menu');
				jQuery('.nav-button').removeClass('hidden').removeClass('active');
			}
		}

		jQuery('.price-list').each(function(){
			equalHeight(jQuery(this).find('.item'));
		});
		
		jQuery('.testimonials-type2').each(function(){
			equalHeight(jQuery(this).find('.quote'));
		});

		jQuery('.blog-type-grid').each(function(){
			equalHeight(jQuery(this).find('.blog-item .content'));
			equalHeight(jQuery(this).find('.blog-item .wrap'));
		});

		equalHeight(jQuery('.woocommerce .products div.product'));
		equalHeight(jQuery('.icon-box'));


		jQuery('.project-horizontal-slider img, .project-horizontal, .project-horizontal-img').css('height', jQuery(window).outerHeight()-jQuery('.header-space:not(.hide)').height()-jQuery('.site-footer').outerHeight()-jQuery('#wpadminbar').outerHeight());
		jQuery('.project-horizontal .cell').css('height', jQuery('.project-horizontal').outerHeight());

		jQuery('.testimonials.full .image,.testimonials.full .cell').css('height', jQuery(window).outerHeight()-jQuery('.header-space:not(.hide)').outerHeight()-jQuery('#wpadminbar').outerHeight());
	});

	/*------------------------------------------------------------------
	[ Right click disable ]
	*/

	jQuery('.right-click-disable').on('contextmenu', function() {
		jQuery('.right-click-disable-message').addClass('active');
		return false;
	});

	jQuery('.right-click-disable-message:not(.lic)').on('click', function() {
		jQuery(this).removeClass('active');
		return false;
	});

	/*------------------------------------------------------------------
	[ Project horizontal slider ]
	*/
	jQuery('.project-horizontal-slider').each(function(){
		var head_slider = jQuery(this);
		if(head_slider.find('.item').length > 1){
			head_slider.imagesLoaded( function() {
				head_slider.addClass('owl-carousel').owlCarousel({
					items:1,
					nav: true,
					dots: false,
					autoplay: false,
					autoWidth: true,
					navClass: ['owl-prev base-icons-arrow-point-to-right','owl-next base-icons-arrow-point-to-left'],
					navText: false,
					margin: 30,
					responsive:{
						0:{
							nav: false,
						},
						480:{

						},
						768:{
							nav: true,
						},
					}
				});
			});
		}
	});


    /*------------------------------------------------------------------
	[ Scroll top button ]
	*/

	jQuery('#scroll-top').on("click", function(){
		jQuery('body, html').animate({ scrollTop: '0' }, 1100); 
		return false;
	});

    /*------------------------------------------------------------------
	[ Fix centered container ]
	*/
	jQuery(window).on("load resize", function(){
		jQuery('.centered-container').each(function() {
			var width = parseInt(Math.round(jQuery(this).width()).toFixed(0)),
				height = parseInt(Math.round(jQuery(this).height()).toFixed(0));

			jQuery(this).css('width', '').css('height', '');

			if ( width & 1 ) {jQuery(this).css('width', (width+1)+'px');}

			if ( height & 1 ) {jQuery(this).css('height', (height+1)+'px');}
		});
	});
	
	jQuery(window).on("load", function(){
		/*------------------------------------------------------------------
		[ Post gallery masonry ]
		*/
		jQuery('.post-gallery-masonry').each(function(){
			var $grid = jQuery(this).isotope({
				itemSelector: 'div',
				horizontalOrder: true
			});
		});

		/*------------------------------------------------------------------
		[ Blog items & filtering ]
		*/
		jQuery('.blog-items').each(function(){
			var $grid = jQuery(this).isotope({
				itemSelector: 'article',
				horizontalOrder: true
			});

			jQuery(this).prev('.filter-button-group').on( 'click', 'button', function() {
				jQuery(this).addClass('active').siblings().removeClass('active');
				var filterValue = jQuery(this).attr('data-filter');
				$grid.isotope({ filter: filterValue });
				jQuery(window).trigger('resize').trigger('scroll');
			});
		});

		/*------------------------------------------------------------------
		[ Portfolio items & filtering ]
		*/
		jQuery('.portfolio-items').each(function(){
			var $grid = jQuery(this).isotope({
				itemSelector: 'article',
				masonry: {
				    columnWidth: '.grid-sizer',
				    horizontalOrder: true
				}
			});

			jQuery(this).prev('.filter-button-group').on( 'click', 'button', function() {
				jQuery(this).addClass('active').siblings().removeClass('active');
				var filterValue = jQuery(this).attr('data-filter');
				$grid.isotope({ filter: filterValue });
				jQuery(window).trigger('resize').trigger('scroll');
			});
		});

		/*------------------------------------------------------------------
		[ Category items ]
		*/
		jQuery('.category-items-t3').each(function(){
			var $grid = jQuery(this).isotope({
				itemSelector: '.col-xs-12',
				masonry: {
				    horizontalOrder: true
				}
			});
		});
	});

	/*------------------------------------------------------------------
	[ Comment reply ]
	*/

	jQuery('.replytocom').on('click', function(){
		var id_parent = jQuery(this).attr('data-id');
		jQuery('#comment_parent').val(id_parent);
		jQuery('#respond').appendTo(jQuery(this).parents('.comment-item'));
		jQuery('#cancel-comment-reply-link').show();
		return false;
	});

	jQuery('#cancel-comment-reply-link').on('click', function(){
		jQuery('#comment_parent').val('0');
		jQuery('#respond').appendTo(jQuery('#commentform-area'));
		jQuery('#cancel-comment-reply-link').hide();
		return false;
	});

	/*------------------------------------------------------------------
	[ Parallax ]
	*/

	jQuery(window).on('load scroll', function(){
		jQuery('.background-parallax').each(function(){
			var wScroll = jQuery(window).scrollTop()-jQuery(this).parent().offset().top+jQuery('#wpadminbar').height()+jQuery('.header-space').height();
	 		jQuery(this).css('transform', 'translate(0px,' + wScroll + 'px)');
	 		jQuery(this).parents('.owl-carousel').find('.owl-nav div').css('margin-top', wScroll);
		});
	});

	/*------------------------------------------------------------------
	[ Quantity ]
	*/

	jQuery('.quantity .down').on("click", function(){
		var val = jQuery(this).parent().find('.input-text').val();
		if(val > 1) {
			val = parseInt(val) - 1;
			jQuery(this).parent().find('.input-text').val(val);
		}
		return false;
	});

	jQuery('.quantity .up').on("click", function(){
		var val = jQuery(this).parent().find('.input-text').val();
		val = parseInt(val) + 1;
		jQuery(this).parent().find('.input-text').val(val);
		return false;
	});

	/*------------------------------------------------------------------
	[ Skills animation ]
	*/

	jQuery(window).on('load scroll', function(){
		jQuery('.skill-item .chart').each(function(){
			var top = jQuery(document).scrollTop()+jQuery(window).height();
			var pos_top = jQuery(this).offset().top;
			if (top > pos_top) {
				jQuery(this).addClass('animated');
			}
		});
	});

    /*------------------------------------------------------------------
	[ Background item ]
	*/

	jQuery('.jquery-background-video').each(function() {
		jQuery(this).bgVideo({showPausePlay: false});
	});

	jQuery(document).on('click', '[href="#"]', function() {
		return false;
	});


	if(jQuery('.popup-gallery').length > 0) {
		
	    jQuery('body').append('<div class="pswp" tabindex="-1" role="dialog" aria-hidden="true"> <div class="pswp__bg"></div><div class="pswp__scroll-wrap"> <div class="pswp__container"> <div class="pswp__item"></div><div class="pswp__item"></div><div class="pswp__item"></div></div><div class="pswp__ui pswp__ui--hidden"> <div class="pswp__top-bar"> <div class="pswp__counter"></div><button class="pswp__button pswp__button--close" title="Close (Esc)"></button> <button class="pswp__button pswp__button--share" title="Share"></button> <button class="pswp__button pswp__button--fs" title="Toggle fullscreen"></button> <button class="pswp__button pswp__button--zoom" title="Zoom in/out"></button> <div class="pswp__preloader"> <div class="pswp__preloader__icn"> <div class="pswp__preloader__cut"> <div class="pswp__preloader__donut"></div></div></div></div></div><div class="pswp__share-modal pswp__share-modal--hidden pswp__single-tap"> <div class="pswp__share-tooltip"></div></div><button class="pswp__button pswp__button--arrow--left" title="Previous (arrow left)"> </button> <button class="pswp__button pswp__button--arrow--right" title="Next (arrow right)"> </button> <div class="pswp__caption"> <div class="pswp__caption__center"></div></div></div></div></div>')
		var $pswp = jQuery('.pswp')[0];

        jQuery(document).on('click', '.popup-gallery .popup-item a', function(event) {
	        if(!jQuery(this).hasClass('permalink')) {
			    var image = [];
		        var $pic     = jQuery(this).parents('.popup-gallery');

	       		var getItems = function() {
	                var items = [],
	                	$el = '';
	                if($pic.hasClass('owl-carousel')) {
	                	$el = $pic.find('.owl-item:not(.cloned) a:visible');
	                } else {
	                	$el = $pic.find('a:not(.permalink)');
	                }
	                $el.each(function() {
	                    var $href   = jQuery(this).attr('href'),
	                        $size   = jQuery(this).data('size').split('x'),
	                        $width  = $size[0],
	                        $height = $size[1];

	                    if(jQuery(this).data('type') == 'video') {
	                    	var item = {
	                    		html: jQuery(this).data('video')
	                    	};
	                    } else {
		                    var item = {
		                        src : $href,
		                        w   : $width,
		                        h   : $height
		                    }
		                }

	                    items.push(item);
	                });
	                return items;
	            }

		        var items = getItems();

		        jQuery.each(items, function(index, value) {
		            image[index]     = new Image();
		            if(value['src']) {
		            	image[index].src = value['src'];
		            }
		        });

	            event.preventDefault();
	            
	            var $index = jQuery(this).parents('.popup-item').index();
	            
	            if(jQuery(this).parent().hasClass('thumbnails')) {
	            	$index++;
	            }
	            if(jQuery(this).parent().parent().hasClass('owl-item')) {
	            	$index = jQuery(this).data('id');
	            	console.log($index);
	            }
	            if(jQuery(this).parents('.popup-gallery').find('.grid-sizer').length > 0) {
	            	$index = $index-1;
	            }
	            var options = {
	                index: $index,
	                bgOpacity: 0.7,
	                showHideOpacity: true
	            }

	            var lightBox = new PhotoSwipe($pswp, PhotoSwipeUI_Default, items, options);
	            lightBox.init();

	            lightBox.listen('beforeChange', function() {
	            	var currItem = jQuery(lightBox.currItem.container);
	            	jQuery('.pswp__video').removeClass('active');
	            	var currItemIframe = currItem.find('.pswp__video').addClass('active');
	            	jQuery('.pswp__video').each(function() {
	            		if (!jQuery(this).hasClass('active')) {
	            			jQuery(this).attr('src', jQuery(this).attr('src'));
	            		}
	            	});
	            });

	            lightBox.listen('close', function() {
	            	jQuery('.pswp__video').each(function() {
	            		jQuery(this).attr('src', jQuery(this).attr('src'));
	            	});
	            });
	        }
        });
	}
});

