<?php

    if ( ! class_exists( 'Redux' ) ) {
        return;
    }

    $opt_name = "narrative_theme";
    $opt_name = apply_filters( 'narrative_theme/opt_name', $opt_name );

    $theme = wp_get_theme();

    $args = array(
        'opt_name'             => $opt_name,
        'display_name'         => $theme->get( 'Name' ),
        'display_version'      => $theme->get( 'Version' ),
        'menu_type'            => 'menu',
        'allow_sub_menu'       => true,
        'menu_title'           => esc_html__( 'Theme Options', 'narrative' ),
        'page_title'           => esc_html__( 'Theme Options', 'narrative' ),
        'google_api_key'       => '',
        'google_update_weekly' => false,
        'async_typography'     => true,
        'admin_bar'            => true,
        'admin_bar_icon'       => 'dashicons-portfolio',
        'admin_bar_priority'   => 50,
        'global_variable'      => '',
        'dev_mode'             => false,
        'update_notice'        => true,
        'customizer'           => true,
        'page_priority'        => null,
        'page_parent'          => 'themes.php',
        'page_permissions'     => 'manage_options',
        'menu_icon'            => '',
        'last_tab'             => '',
        'page_icon'            => 'icon-themes',
        'page_slug'            => '',
        'save_defaults'        => true,
        'default_show'         => false,
        'default_mark'         => '',
        'show_import_export'   => true,
        'transient_time'       => 60 * MINUTE_IN_SECONDS,
        'output'               => true,
        'output_tag'           => true,
        'database'             => '',
        'use_cdn'              => true,
        'show_options_object'  => false
    );

    Redux::setArgs( $opt_name, $args );

    // Memory use

    if(function_exists('memory_get_usage')) {
        $memory_get_usage = max( narrative_let_to_num( WP_MEMORY_LIMIT ), narrative_let_to_num( @ini_get( 'memory_limit' ) ) );
        if ( $memory_get_usage < 67108864 ) {
            /* Translators: %1$s: Memory limit, %2$s: Docs link. */
            $memory_get_usage = '<span class="error"><i class="fa fa-exclamation-circle"></i> ' . sprintf( esc_html__( '%1$s - We recommend setting memory to at least 64MB. See: %2$s', 'narrative' ), esc_html( size_format( $memory_get_usage ) ), '<a href="https://codex.wordpress.org/Editing_wp-config.php#Increasing_memory_allocated_to_PHP" target="_blank">' . esc_html__( 'Increasing memory allocated to PHP', 'narrative' ) . '</a>' ) . '</span>';
        } else {
            $memory_get_usage = '<span class="green">' . esc_html( size_format( $memory_get_usage ) ) . '</span>';
        }
    } else {
        $memory_get_usage = '-';
    }

    // Debug mode

    if(( defined( 'WP_DEBUG' ) && WP_DEBUG ) == 1) {
        $debug_mode = '<i class="fa fa-check green"></i>';
    } else {
        $debug_mode = '<i class="fa fa-times red"></i>';
    }

    // Language

    if(function_exists('get_locale')) {
        $language = get_locale();
    } else {
        $language = '-';
    }

    // php version
    if ( version_compare( phpversion(), '7.2', '>=' ) ) {
        $phpversion = '<span class="green">' . esc_html( phpversion() ) . '</span>';
    } else {
        $update_link = ' <a href="https://wordpress.org/support/upgrade-php/" target="_blank">' . esc_html__( 'How to update your PHP version', 'narrative' ) . '</a>';
        $notice = '';
        if ( version_compare( phpversion(), '5.4', '<' ) ) {
            $notice = esc_html__( 'WooCommerce will run under this version of PHP, however, some features such as geolocation are not compatible. Support for this version will be dropped in the next major release. We recommend using PHP version 7.2 or above for greater performance and security.', 'narrative' ) . $update_link;
        } elseif ( version_compare( phpversion(), '5.6', '<' ) ) {
            $notice = esc_html__( 'WooCommerce will run under this version of PHP, however, it has reached end of life. We recommend using PHP version 7.2 or above for greater performance and security.', 'narrative' ) . $update_link;
        } elseif ( version_compare( phpversion(), '7.2', '<' ) ) {
            $notice = esc_html__( 'We recommend using PHP version 7.2 or above for greater performance and security.', 'narrative' ) . $update_link;
        }

        $phpversion = '<span class="error"><i class="fa fa-exclamation-circle"></i> ' . esc_html( phpversion() ) . ' - ' . wp_kses_post( $notice ) . '</span>';
    }

    // max execution time

    if(ini_get( 'max_execution_time' ) < 600 && ini_get( 'max_execution_time' ) != 0 && ini_get( 'max_execution_time' ) != -1) {
        $max_execution_time = ini_get( 'max_execution_time' ).' - <i class="fa fa-times red"></i> '.esc_html__('We recommended 600 and more.', 'narrative');
    } else {
        $max_execution_time = ini_get( 'max_execution_time' );
    }

    // post max size

    if(narrative_let_to_num( ini_get( 'post_max_size' ) ) < 52428800) {
        $post_max_size = '<span class="error">'.size_format(narrative_let_to_num( ini_get( 'post_max_size' ) )).' - <i class="fa fa-times red"></i> '.esc_html__('We recommended  50MB and more.', 'narrative').'</span>';
    } else {
        $post_max_size = '<span class="green">'.size_format(narrative_let_to_num( ini_get( 'post_max_size' ) )).'</span>';
    }

    // max upload size

    if(wp_max_upload_size() < 104857600) {
        $max_upload_size = '<span class="error">'.size_format(wp_max_upload_size()).' - <i class="fa fa-times red"></i> '.esc_html__('We recommended 100MB and more.', 'narrative').'</span>';
    } else {
        $max_upload_size = '<span class="green">'.size_format(wp_max_upload_size()).'</span>';
    }

    $info_html = '
<table class="redux-info-table" cellspacing="0">
    <thead>
        <tr>
            <th colspan="3">'.esc_html__('WordPress Environment', 'narrative').'</th>
        </tr>
    </thead>
    <tbody>
        <tr>
            <td class="title">'.esc_html__('Home URL:', 'narrative').'</td>
            <td class="help"><a href="#" title="'.esc_html__('The URL of your site`s homepage.', 'narrative').'" class="tooltipster fa fa-info-circle"></a></td>
            <td class="value">'.strip_tags(get_option( 'home' )).'</td>
        </tr>
        <tr>
            <td class="title">'.esc_html__('Site URL:', 'narrative').'</td>
            <td class="help"><a href="#" title="'.esc_html__('The root URL of your site.', 'narrative').'" class="tooltipster fa fa-info-circle"></a></td>
            <td class="value">'.strip_tags(get_option( 'siteurl' )).'</td>
        </tr>
        <tr>
            <td class="title">'.esc_html__('WP Version:', 'narrative').'</td>
            <td class="help"><a href="#" title="'.esc_html__('The version of WordPress installed on your site.', 'narrative').'" class="tooltipster fa fa-info-circle"></a></td>
            <td class="value">'.wp_kses_post(get_bloginfo( 'version' )).'</td>
        </tr>
        <tr>
            <td class="title">'.esc_html__('WP Memory Limit:', 'narrative').'</td>
            <td class="help"><a href="#" title="'.esc_html__('The maximum amount of memory (RAM) that your site can use at one time.', 'narrative').'" class="tooltipster fa fa-info-circle"></a></td>
            <td class="value">'.wp_kses_post($memory_get_usage).'</td>
        </tr>
        <tr>
            <td class="title">'.esc_html__('WP Debug Mode:', 'narrative').'</td>
            <td class="help"><a href="#" title="'.esc_html__('Displays whether or not WordPress is in Debug Mode.', 'narrative').'" class="tooltipster fa fa-info-circle"></a></td>
            <td class="value">'.wp_kses_post($debug_mode).'</td>
        </tr>
        <tr>
            <td class="title">'.esc_html__('Language:', 'narrative').'</td>
            <td class="help"><a href="#" title="'.esc_html__('The current language used by WordPress. Default = English', 'narrative').'" class="tooltipster fa fa-info-circle"></a></td>
            <td class="value">'.strip_tags($language).'</td>
        </tr>
    </tbody>
</table>

<table class="redux-info-table" cellspacing="0">
    <thead>
        <tr>
            <th colspan="3">'.esc_html__('Server Environment', 'narrative').'</th>
        </tr>
    </thead>
    <tbody>
        <tr>
            <td class="title">'.esc_html__('Server Info:', 'narrative').'</td>
            <td class="help"><a href="#" title="'.esc_html__('Information about the web server that is currently hosting your site.', 'narrative').'" class="tooltipster fa fa-info-circle"></a></td>
            <td class="value">'.strip_tags($_SERVER['SERVER_SOFTWARE']).'</td>
        </tr>
        <tr>
            <td class="title">'.esc_html__('PHP Version:', 'narrative').'</td>
            <td class="help"><a href="#" title="'.esc_html__('The version of PHP installed on your hosting server.', 'narrative').'" class="tooltipster fa fa-info-circle"></a></td>
            <td class="value">'.wp_kses_post($phpversion).'</td>
        </tr>
        <tr>
            <td class="title">'.esc_html__('PHP Post Max Size:', 'narrative').'</td>
            <td class="help"><a href="#" title="'.esc_html__('The largest file size that can be contained in one post.', 'narrative').'" class="tooltipster fa fa-info-circle"></a></td>
            <td class="value">'.wp_kses_post($post_max_size).'</td>
        </tr>
        <tr>
            <td class="title">'.esc_html__('PHP Max Execution Time:', 'narrative').'</td>
            <td class="help"><a href="#" title="'.esc_html__('The amount of time (in seconds) that your site will spend on a single operation before timing out (to avoid server lockups)', 'narrative').'" class="tooltipster fa fa-info-circle"></a></td>
            <td class="value">'.wp_kses_post($max_execution_time).'</td>
        </tr>
        <tr>
            <td class="title">'.esc_html__('Max Upload Size:', 'narrative').'</td>
            <td class="help"><a href="#" title="'.esc_html__('The largest filesize that can be uploaded to your WordPress installation.', 'narrative').'" class="tooltipster fa fa-info-circle"></a></td>
            <td class="value">'.wp_kses_post($max_upload_size).'</td>
        </tr>
    </tbody>
</table>
<table class="redux-info-table" cellspacing="0">
    <thead>
        <tr>
            <th colspan="3">'.esc_html__('Theme', 'narrative').'</th>
        </tr>
    </thead>
    <tbody>
        <tr>
            <td class="title">'.esc_html__('Name:', 'narrative').'</td>
            <td class="help"><a href="#" title="'.esc_html__('The name of the current active theme.', 'narrative').'" class="tooltipster fa fa-info-circle"></a></td>
            <td class="value">'.strip_tags(wp_get_theme()->get('Name')).'</td>
        </tr>
        <tr>
            <td class="title">'.esc_html__('Version:', 'narrative').'</td>
            <td class="help"><a href="#" title="'.esc_html__('The installed version of the current active theme.', 'narrative').'" class="tooltipster fa fa-info-circle"></a></td>
            <td class="value">'.strip_tags(wp_get_theme()->get('Version')).'</td>
        </tr>
    </tbody>
</table>
    ';

    Redux::setSection( $opt_name, array(
        'title'            => esc_html__( 'General', 'narrative' ),
        'id'               => 'general',
        'customizer_width' => '400px',
        'icon'             => 'fa fa-home',
        'fields'           => array(
            array(
                'id'       => 'site_color_mode',
                'type'     => 'select',
                'title'    => esc_html__('Site color mode', 'narrative'), 
                'options'  => array(
                    'light' => esc_html__('Light', 'narrative'),
                    'dark' => esc_html__('Dark', 'narrative'),
                ),
                'default'  => 'light',
            ),
            array(
                'id'       => 'copyright_text',
                'type'     => 'text',
                'title'    => esc_html__('Copyright text', 'narrative'),
            ),
            array(
                'id'       => 'decor_color',
                'type'     => 'color',
                'title'    => esc_html__('Main Color', 'narrative'),
                'validate' => 'color',
                'default'    => '#0054fc',
                'transparent' => false,
                'output'      => array(
                    'background-color' => '.banner .owl-dot:after, .skill-item .line div, .portfolio_hover_type_2 .portfolio-item .content h5:after, .portfolio_hover_type_4 .portfolio-item .content h5:after, .portfolio_hover_type_5 .portfolio-item .content h5:before, .portfolio_hover_type_6 .portfolio-item .content h5:after, .portfolio_hover_type_7 .portfolio-item .content h5:after, .portfolio_hover_type_7 .portfolio-item .content h5:before, .portfolio_hover_type_8 .portfolio-item .content h5:after, .portfolio_hover_type_8 .portfolio-item .content h5:before, .portfolio_hover_type_9 .portfolio-item .content h5:after, .portfolio_hover_type_9 .portfolio-item .content h5:before, .vc_general.vc_btn3:hover, .woocommerce .products .product .image .button, .minicart-wrap a.checkout, .widget_shopping_cart_content a.checkout, .woocommerce div.product form.cart .button, .woocommerce div.product .woocommerce-tabs .tabs li a:after, .preloader-folding-cube .preloader-cube:before, .portfolio-slider .item .button, .portfolio-slider .owl-nav .owl-next, .button-style1:hover, .vc_general.vc_btn3:hover, .portfolio-split-screen .categories a, .testimonials-type2 .owl-dots .owl-dot.active, .portfolio-split-screen .slider .owl-dot.active,.category-items-t2 .owl-nav div, .button-style1.colored, .portfolio-slider-style2 .portfolio-slider .owl-nav div, .portfolio-slider-style3 .portfolio-slider .owl-nav div, .portfolio-slider .item .bottom .cat a, .blog-item .categories a, .heading-decor.line-on-bottom:after, .heading-decor-s.line-on-bottom:after, .decor-text:before, .subscribe-form.type2 .button-style1, .woocommerce div.product .summary .categories a',

                    'border-color' => '.banner-style1.banner .owl-dot.active:before, .price-list .item .options, .price-list .item .o-row:not(:last-of-type):after, .testimonials .item .image .img2, .testimonials-type2 .image div, .portfolio_hover_type_3 .portfolio-item .content, .portfolio_hover_type_6 .portfolio-item .content, .portfolio_hover_type_4 .portfolio-item .content, .portfolio_hover_type_4 .portfolio-item:hover .content, .vc_general.vc_btn3, .woocommerce .woocommerce-ordering select, .woocommerce nav.woocommerce-pagination ul li a:focus, .woocommerce nav.woocommerce-pagination ul li a:hover, .woocommerce nav.woocommerce-pagination ul li span.current, .woocommerce form .form-row select, .woocommerce form .form-row input.input-text, .woocommerce form .form-row textarea, .select2-container--default .select2-selection--single, .select2-dropdown, .pagination .current',

                    'color' => '.banner-about .sub-heading, .banner-contacts .sub-heading, .banner-social-buttons a:hover, .navigation > ul > li:hover > a, .navigation .sub-menu li.current-menu-item > a, .navigation .sub-menu li.current-menu-ancestor > a, .navigation .sub-menu li:hover > a, .navigation .sub-menu li.current-menu-item.menu-item-has-children:after, .navigation .sub-menu li:hover.menu-item-has-children:after, .navigation .children li.current_page_item > a, .navigation .children li.current-menu-ancestor > a, .navigation .children li:hover > a, .navigation .children li.current_page_item.page_item_has_children:after, .navigation .children li:hover.page_item_has_children:after, .navigation > ul > li.current-menu-item > a, .navigation > ul > li.current-menu-ancestor > a, .navigation > ul > li.current_page_item > a, .navigation > ul > li.current-menu-ancestor > a, .filter-button-group button:after, .filter-button-group a:after, .category-buttons a:after, .side-navigation li.current-menu-item > a, .side-navigation li.current-menu-parent > a, .side-navigation li.current-menu-ancestor > a, .side-navigation li.current_page_item > a, .side-navigation li:hover > a, .project-horizontal .content .date, .contact-row .icon, .widget_archive ul li a:hover, .widget_categories ul li a:hover, .widget_pages ul li a:hover, .widget_meta ul li a:hover, .widget_nav_menu ul li a:hover, .widget_recent_entries ul li a:hover, .site-content .date, .team-social-buttons a:hover, .minicart-wrap .cart_list .mini_cart_item .quantity, .widget_shopping_cart_content .cart_list .mini_cart_item .quantity, .minicart-wrap .total > span, .widget_shopping_cart_content .total > span, .woocommerce .cart-collaterals table.shop_table.woocommerce-checkout-review-order-table td .amount, .woocommerce div.product .price-area, .comment-items .comment-item .text .date, .video-block a i:hover, .woocommerce .cart .up:hover, .woocommerce .cart .down:hover, .woocommerce div.product .woocommerce-tabs .tabs li.active, .icon-box-style3 .icon, .filter-button-group button.active span, .filter-button-group a.active span, .category-buttons a.active span, .hm-cunt span, .portfolio-split-screen-wrap .portfolio-navigation .numbers .num.active, .portfolio-split-screen-wrap .portfolio-navigation .numbers .num:hover, .portfolio-split-screen .link i, .button-style2.colored, .tabs .tabs-head .item.active-tab, .icon-box .icon, .button-readmore i, .banner .cell .price > span, .banner .cell .price ins, .number-box .icon, blockquote:before, .icon-box-style2 .icon, .button-readmore:hover',

                    'stroke' => '',

                    'fill' => '.video-block a i:hover path'
                ),
            ),
            array(
                'id'       => 'right_click_disable',
                'type'     => 'switch',
                'title'    => esc_html__('Right click disable', 'narrative'),
                'default'  => false,
            ),
            array(
                'id'       => 'right_click_disable_message',
                'type'     => 'editor',
                'title'    => esc_html__('Message', 'narrative'),
                'default'  => __('<p style="text-align: center"><strong><span style="font-size: 18px">Content is protected. Right-click function is disabled.</span></strong></p>', 'narrative'),
                'args'   => array(
                    'teeny'            => false,
                    'textarea_rows'    => 5
                ),
                'required' => array('right_click_disable','=',1)
            ),
            array(
                'id'       => 'protected_message',
                'type'     => 'editor',
                'title'    => esc_html__('Protected Page Message', 'narrative'),
                'default'  => esc_html__( 'This content is password protected. To view it please enter your password below:', 'narrative' ),
                'args'   => array(
                    'teeny'            => false,
                    'textarea_rows'    => 5
                ),
            ),
        )
    ) );

    Redux::setSection( $opt_name, array(
        'title'            => esc_html__( 'Preloader', 'narrative' ),
        'id'               => 'general_preloader',
        'customizer_width' => '450px',
        'subsection'       => true,
        'icon'             => 'fa fa-spinner',
        'fields'     => array(
            array(
                'id'       => 'preloader_show',
                'type'     => 'switch', 
                'title'    => esc_html__('Preloader', 'narrative'),
                'default'  => true,
            ),
        )
    ) );


    Redux::setSection( $opt_name, array(
        'title'            => esc_html__( 'Header', 'narrative' ),
        'id'               => 'header',
        'customizer_width' => '400px',
        'icon'             => 'fa fa-header',
    ) );

    Redux::setSection( $opt_name, array(
        'title'            => esc_html__( 'Logo', 'narrative' ),
        'id'               => 'header_logo',
        'customizer_width' => '450px',
        'subsection'       => true,
        'icon'             => 'fa fa-flag',
        'fields'     => array(
            array(
                'id'       => 'logo_text',
                'type'     => 'text',
                'title'    => esc_html__('Logo text', 'narrative'),
            ),
            array( 
                'id'       => 'default_logo',
                'type'     => 'background',
                'title'    => esc_html__('Logo Image - normal', 'narrative'),
                'desc'     => esc_html__('Choose a default logo image to display' ,'narrative'),
                'background-attachment' => false,
                'background-position' => false,
                'background-repeat' => false,
                'background-origin' => false,
                'background-color' => false,
                'background-size' => false,
                'background-clip' => false,
                'preview_media' => true,
                'preview' => false,
            ),
            array( 
                'id'       => 'light_logo',
                'type'     => 'background',
                'title'    => esc_html__('Logo Image - light', 'narrative'),
                'desc'     => esc_html__('Choose a logo image to display for "Light" header skin' ,'narrative'),
                'background-attachment' => false,
                'background-position' => false,
                'background-repeat' => false,
                'background-origin' => false,
                'background-color' => false,
                'background-size' => false,
                'background-clip' => false,
                'preview_media' => true,
                'preview' => false,
            ),
            array( 
                'id'       => 'dark_logo',
                'type'     => 'background',
                'title'    => esc_html__('Logo Image - Dark', 'narrative'),
                'desc'     => esc_html__('Choose a logo image to display for "Dark" header skin' ,'narrative'),
                'background-attachment' => false,
                'background-position' => false,
                'background-repeat' => false,
                'background-origin' => false,
                'background-color' => false,
                'background-size' => false,
                'background-clip' => false,
                'preview_media' => true,
                'preview' => false,
            ),
            array(
                'id'       => 'logo_size',
                'units'    => 'px',
                'type'     => 'dimensions',
                'units_extended' => 'false',
                'title'    => esc_html__('Logo max width', 'narrative'),
                'output'      => array('.site-header .logo img, .side-header .logo img, .site-header .logo a, .side-header .logo a'),
                'height'   => true,
            ),
        )
    ) );

    Redux::setSection( $opt_name, array(
        'title'            => esc_html__( 'Header style', 'narrative' ),
        'id'               => 'header_style',
        'customizer_width' => '450px',
        'subsection'       => true,
        'icon'             => 'fa fa-sliders',
        'fields'     => array(
            array(
                'id'       => 'header_style',
                'type'     => 'image_select',
                'title'    => esc_html__('Header style', 'narrative'), 
                'options'  => array(
                    'logo_left'      => array(
                        'alt'   => 'Logo left', 
                        'img'  => get_template_directory_uri().'/theme-settings/imgs/header-style1.png'
                    ),
                    'logo_center'      => array(
                        'alt'   => 'Logo center', 
                        'img'  => get_template_directory_uri().'/theme-settings/imgs/header-style2.png'
                    ),
                    'logo_center_t2'      => array(
                        'alt'   => 'Logo center type2', 
                        'img'  => get_template_directory_uri().'/theme-settings/imgs/header-style4.png'
                    ),
                    'side'      => array(
                        'alt'   => 'Side', 
                        'img'  => get_template_directory_uri().'/theme-settings/imgs/header-style3.png'
                    ),
                ),
                'default' => 'logo_left'
            ),
            array(
                'id'       => 'header_container',
                'type'     => 'select',
                'title'    => esc_html__('Header container', 'narrative'), 
                'options'  => array(
                    'container' => esc_html__('Center container', 'narrative'),
                    'container-fluid' => esc_html__('Full witdh', 'narrative'),
                ),
                'default'  => 'container',
            ),
            array(
                'id'       => 'header_color_mode',
                'type'     => 'select',
                'title'    => esc_html__('Header color mode', 'narrative'), 
                'options'  => array(
                    'dark' => esc_html__('Dark', 'narrative'),
                    'light' => esc_html__('Light', 'narrative'),
                ),
                'default'  => 'light',
            ),
            array(
                'id'       => 'header_bg_color',
                'type'     => 'color',
                'title'    => esc_html__('Header Background Color', 'narrative'),
                'validate' => 'color',
                'transparent' => false,
                'output'      => array('background-color' => '.site-header'),
            ),
            array(
                'id'       => 'header_text_color',
                'type'     => 'color',
                'title'    => esc_html__('Header Text Color', 'narrative'),
                'validate' => 'color',
                'transparent' => false,
                'output'      => array('color' => '.site-header'),
            ),
            array(
                'id'       => 'header_cart',
                'type'     => 'switch', 
                'title'    => esc_html__('Cart', 'narrative'),
                'default'  => true,
            ),
            array(
                'id'       => 'header_search',
                'type'     => 'switch', 
                'title'    => esc_html__('Search', 'narrative'),
                'default'  => true,
            )
        )
    ) );

    Redux::setSection( $opt_name, array(
        'title'            => esc_html__( 'Navigation', 'narrative' ),
        'id'               => 'header_navigation',
        'customizer_width' => '450px',
        'subsection'       => true,
        'icon'             => 'fa fa-bars',
        'fields'     => array(
            array(
                'id'       => 'navigation_type',
                'type'     => 'select',
                'title'    => esc_html__('Navigation type', 'narrative'), 
                'options'  => array(
                    'disabled' => esc_html__('Disabled', 'narrative'),
                    'hidden_menu' => esc_html__('Hidden menu', 'narrative'),
                    'visible_menu' => esc_html__('Visible menu', 'narrative'),
                    'full_screen' => esc_html__('Full screen menu', 'narrative'),
                ),
                'default'  => 'visible_menu',
            ),
        )
    ) );

    Redux::setSection( $opt_name, array(
        'title'            => esc_html__( 'Typography', 'narrative' ),
        'id'               => 'typography',
        'customizer_width' => '400px',
        'icon'             => 'fa fa-font',
        'fields'     => array(
            array(
                'id'          => 'body-font-face',
                'type'        => 'typography', 
                'title'       => esc_html__('Body', 'narrative'),
                'google'      => true, 
                'font-backup' => true,
                'output'      => array('body'),
                'units'       => 'px',
                'text-align'  => false,
                'line-height'  => false,
                'subsets'  => false,
                'all_styles' => true,
                'default'     => array(
                    'color'       => '#000', 
                    'font-style'  => '400', 
                    'font-family' => 'Montserrat', 
                    'google'      => true,
                    'font-size'   => '16px',
                ),
            ),
            array(
                'id'          => 'h1-font-face',
                'type'        => 'typography', 
                'title'       => esc_html__('H1', 'narrative'),
                'google'      => true, 
                'font-backup' => true,
                'output'      => array('h1, .h1'),
                'units'       => 'px',
                'text-align'  => false,
                'line-height'  => false,
                'subsets'  => false,
                'color' => false,
                'default'     => array(
                    'font-style'  => '700', 
                    'font-family' => 'Montserrat', 
                    'google'      => true,
                    'font-size'   => '60px',
                ),
            ),
            array(
                'id'          => 'h2-font-face',
                'type'        => 'typography', 
                'title'       => esc_html__('H2', 'narrative'),
                'google'      => true, 
                'font-backup' => true,
                'output'      => array('h2, .h2'),
                'units'       => 'px',
                'text-align'  => false,
                'line-height'  => false,
                'subsets'  => false,
                'color' => false,
                'default'     => array(
                    'font-style'  => '700', 
                    'font-family' => 'Montserrat', 
                    'google'      => true,
                    'font-size'   => '48px',
                ),
            ),
            array(
                'id'          => 'h3-font-face',
                'type'        => 'typography', 
                'title'       => esc_html__('H3', 'narrative'),
                'google'      => true, 
                'font-backup' => true,
                'output'      => array('h3, .h3'),
                'units'       => 'px',
                'text-align'  => false,
                'line-height'  => false,
                'subsets'  => false,
                'color' => false,
                'default'     => array(
                    'font-style'  => '700', 
                    'font-family' => 'Montserrat', 
                    'google'      => true,
                    'font-size'   => '36px',
                ),
            ),
            array(
                'id'          => 'h4-font-face',
                'type'        => 'typography', 
                'title'       => esc_html__('H4', 'narrative'),
                'google'      => true, 
                'font-backup' => true,
                'output'      => array('h4, .h4'),
                'units'       => 'px',
                'text-align'  => false,
                'line-height'  => false,
                'subsets'  => false,
                'color' => false,
                'default'     => array(
                    'font-style'  => '700', 
                    'font-family' => 'Montserrat', 
                    'google'      => true,
                    'font-size'   => '30px',
                ),
            ),
            array(
                'id'          => 'h5-font-face',
                'type'        => 'typography', 
                'title'       => esc_html__('H5', 'narrative'),
                'google'      => true, 
                'font-backup' => true,
                'output'      => array('h5, .h5'),
                'units'       => 'px',
                'text-align'  => false,
                'line-height'  => false,
                'subsets'  => false,
                'color' => false,
                'default'     => array(
                    'font-style'  => '700', 
                    'font-family' => 'Montserrat', 
                    'google'      => true,
                    'font-size'   => '24px',
                ),
            ),
            array(
                'id'          => 'h6-font-face',
                'type'        => 'typography', 
                'title'       => esc_html__('H6', 'narrative'),
                'google'      => true, 
                'font-backup' => true,
                'output'      => array('h6, .h6'),
                'units'       => 'px',
                'text-align'  => false,
                'line-height'  => false,
                'subsets'  => false,
                'color' => false,
                'default'     => array(
                    'font-style'  => '700', 
                    'font-family' => 'Montserrat', 
                    'google'      => true,
                    'font-size'   => '18px',
                ),
            ),
            array(
                'id'          => 'additional-font-face',
                'type'        => 'typography', 
                'title'       => esc_html__('Additional Font Face', 'narrative'),
                'google'      => true, 
                'font-backup' => true,
                'units'       => 'px',
                'text-align'  => false,
                'line-height' => false,
                'subsets'     => false,
                'font-weight' => false,
                'font-size'   => false,
                'font-style'  => false,
                'color'       => false,
                'all_styles'  => true,
            ),
            array(
                'id'          => 'additional-font-face2',
                'type'        => 'typography', 
                'title'       => esc_html__('Additional Font Face 2', 'narrative'),
                'google'      => true, 
                'font-backup' => true,
                'units'       => 'px',
                'text-align'  => false,
                'line-height' => false,
                'subsets'     => false,
                'font-weight' => false,
                'font-size'   => false,
                'font-style'  => false,
                'color'       => false,
                'all_styles'  => true,
            ),
            array(
                'id'          => 'additional-font-face3',
                'type'        => 'typography', 
                'title'       => esc_html__('Additional Font Face 3', 'narrative'),
                'google'      => true, 
                'font-backup' => true,
                'units'       => 'px',
                'text-align'  => false,
                'line-height' => false,
                'subsets'     => false,
                'font-weight' => false,
                'font-size'   => false,
                'font-style'  => false,
                'color'       => false,
                'all_styles'  => true,
            ),
            array(
                'id'          => 'additional-font-face4',
                'type'        => 'typography', 
                'title'       => esc_html__('Additional Font Face 4', 'narrative'),
                'google'      => true, 
                'font-backup' => true,
                'units'       => 'px',
                'text-align'  => false,
                'line-height' => false,
                'subsets'     => false,
                'font-weight' => false,
                'font-size'   => false,
                'font-style'  => false,
                'color'       => false,
                'all_styles'  => true,
            ),
        )
    ) );

    Redux::setSection( $opt_name, array(
        'title'            => esc_html__( 'Social buttons', 'narrative' ),
        'id'               => 'social_buttons',
        'customizer_width' => '400px',
        'icon'             => 'fa fa-twitter',
        'fields'     => array(
            array(
                'id'       => 'footer_social_buttons',
                'type'     => 'switch', 
                'title'    => esc_html__('Social buttons in footer', 'narrative'),
                'default'  => true,
            ),
            array(
                'id'       => 'social_target',
                'type'     => 'select',
                'title'    => esc_html__('Open link in', 'narrative'), 
                'options'  => array(
                    '_self' => esc_html__('Current Tab', 'narrative'),
                    '_blank' => esc_html__('New Tab', 'narrative'),
                ),
            ),
            array(
                'id'       => 'sl1',
                'type'     => 'label',
                'title'    => esc_html__('Social button 1', 'narrative'),
            ),
            array(
                'id'       => 'social_icon1',
                'type'     => 'select',
                'title'    => esc_html__('Social icon', 'narrative'), 
                'options'  => array(
                    '' => esc_html__('---', 'narrative'),
                    'fa fa-500px,none,500px' => esc_html__('500px', 'narrative'),
                    'fa fa-behance,social-icon-color-behance,Behance' => esc_html__('Behance', 'narrative'),
                    'fa fa-deviantart,social-icon-color-deviantart,Deviantart' => esc_html__('Deviantart', 'narrative'),
                    'fa fa-dribbble,social-icon-color-dribbble,Dribbble' => esc_html__('Dribbble', 'narrative'),
                    'fa fa-dropbox,social-icon-color-dropbox,Dropbox' => esc_html__('Dropbox', 'narrative'),
                    'fa fa-facebook,social-icon-color-facebook,Facebook' => esc_html__('Facebook', 'narrative'),
                    'fa fa-flickr,social-icon-color-flickr,Flickr' => esc_html__('Flickr', 'narrative'),
                    'fa fa-foursquare,social-icon-color-foursquare,Foursquare' => esc_html__('Foursquare', 'narrative'),
                    'fa fa-google,social-icon-color-google-plus,Google-Plus' => esc_html__('Google-Plus', 'narrative'),
                    'fa fa-instagram,social-icon-color-instagram,Instagram' => esc_html__('Instagram', 'narrative'),
                    'fa fa-line,social-icon-color-line,Line' => esc_html__('Line', 'narrative'),
                    'fa fa-linkedin,social-icon-color-linkedin,LinkedIn' => esc_html__('LinkedIn', 'narrative'),
                    'fa fa-pinterest,social-icon-color-pinterest,Pinterest' => esc_html__('Pinterest', 'narrative'),
                    'fa fa-quora,social-icon-color-quora,Quora' => esc_html__('Quora', 'narrative'),
                    'fa fa-skype,social-icon-color-skype,Skype' => esc_html__('Skype', 'narrative'),
                    'fa fa-snapchat-ghost,social-icon-color-snapchat,Snapchat' => esc_html__('Snapchat', 'narrative'),
                    'fa fa-soundcloud,social-icon-color-soundcloud,Soundcloud' => esc_html__('Soundcloud', 'narrative'),
                    'fa fa-spotify,social-icon-color-spotify,Spotify' => esc_html__('Spotify', 'narrative'),
                    'fa fa-telegram-plane,social-icon-color-telegram,Telegram' => esc_html__('Telegram', 'narrative'),
                    'fa fa-tumblr,social-icon-color-tumblr,Tumblr' => esc_html__('Tumblr', 'narrative'),
                    'fa fa-twitter,social-icon-color-twitter,Twitter' => esc_html__('Twitter', 'narrative'),
                    'fa fa-viber,social-icon-color-viber,Viber' => esc_html__('Viber', 'narrative'),
                    'fa fa-vimeo-square,social-icon-color-vimeo,Vimeo' => esc_html__('Vimeo', 'narrative'),
                    'fa fa-vine,social-icon-color-vine,Vine' => esc_html__('Vine', 'narrative'),
                    'fa fa-whatsapp,social-icon-color-whatsapp,WhatsApp' => esc_html__('WhatsApp', 'narrative'),
                    'fa fa-yelp,social-icon-color-yelp,Yelp' => esc_html__('Yelp', 'narrative'),
                    'fa fa-youtube,social-icon-color-youtube,YouYube' => esc_html__('YouYube', 'narrative'),
                ),
                'default'  => '',
            ),
            array(
                'id'       => 'social_link1',
                'type'     => 'text',
                'title'    => esc_html__('Link', 'narrative'),
            ),
            array(
                'id'       => 'sb2',
                'type'     => 'label',
                'title'    => esc_html__('Social button 2', 'narrative'),
            ),
            array(
                'id'       => 'social_icon2',
                'type'     => 'select',
                'title'    => esc_html__('Social icon', 'narrative'), 
                'options'  => array(
                    '' => esc_html__('---', 'narrative'),
                    'fa fa-500px,none,500px' => esc_html__('500px', 'narrative'),
                    'fa fa-behance,social-icon-color-behance,Behance' => esc_html__('Behance', 'narrative'),
                    'fa fa-deviantart,social-icon-color-deviantart,Deviantart' => esc_html__('Deviantart', 'narrative'),
                    'fa fa-dribbble,social-icon-color-dribbble,Dribbble' => esc_html__('Dribbble', 'narrative'),
                    'fa fa-dropbox,social-icon-color-dropbox,Dropbox' => esc_html__('Dropbox', 'narrative'),
                    'fa fa-facebook,social-icon-color-facebook,Facebook' => esc_html__('Facebook', 'narrative'),
                    'fa fa-flickr,social-icon-color-flickr,Flickr' => esc_html__('Flickr', 'narrative'),
                    'fa fa-foursquare,social-icon-color-foursquare,Foursquare' => esc_html__('Foursquare', 'narrative'),
                    'fa fa-google,social-icon-color-google-plus,Google-Plus' => esc_html__('Google-Plus', 'narrative'),
                    'fa fa-instagram,social-icon-color-instagram,Instagram' => esc_html__('Instagram', 'narrative'),
                    'fa fa-line,social-icon-color-line,Line' => esc_html__('Line', 'narrative'),
                    'fa fa-linkedin,social-icon-color-linkedin,LinkedIn' => esc_html__('LinkedIn', 'narrative'),
                    'fa fa-pinterest,social-icon-color-pinterest,Pinterest' => esc_html__('Pinterest', 'narrative'),
                    'fa fa-quora,social-icon-color-quora,Quora' => esc_html__('Quora', 'narrative'),
                    'fa fa-skype,social-icon-color-skype,Skype' => esc_html__('Skype', 'narrative'),
                    'fa fa-snapchat-ghost,social-icon-color-snapchat,Snapchat' => esc_html__('Snapchat', 'narrative'),
                    'fa fa-soundcloud,social-icon-color-soundcloud,Soundcloud' => esc_html__('Soundcloud', 'narrative'),
                    'fa fa-spotify,social-icon-color-spotify,Spotify' => esc_html__('Spotify', 'narrative'),
                    'fa fa-telegram-plane,social-icon-color-telegram,Telegram' => esc_html__('Telegram', 'narrative'),
                    'fa fa-tumblr,social-icon-color-tumblr,Tumblr' => esc_html__('Tumblr', 'narrative'),
                    'fa fa-twitter,social-icon-color-twitter,Twitter' => esc_html__('Twitter', 'narrative'),
                    'fa fa-viber,social-icon-color-viber,Viber' => esc_html__('Viber', 'narrative'),
                    'fa fa-vimeo-square,social-icon-color-vimeo,Vimeo' => esc_html__('Vimeo', 'narrative'),
                    'fa fa-vine,social-icon-color-vine,Vine' => esc_html__('Vine', 'narrative'),
                    'fa fa-whatsapp,social-icon-color-whatsapp,WhatsApp' => esc_html__('WhatsApp', 'narrative'),
                    'fa fa-yelp,social-icon-color-yelp,Yelp' => esc_html__('Yelp', 'narrative'),
                    'fa fa-youtube,social-icon-color-youtube,YouYube' => esc_html__('YouYube', 'narrative'),
                ),
                'default'  => '',
            ),
            array(
                'id'       => 'social_link2',
                'type'     => 'text',
                'title'    => esc_html__('Link', 'narrative'),
            ),
            array(
                'id'       => 'sb3',
                'type'     => 'label',
                'title'    => esc_html__('Social button 3', 'narrative'),
            ),
            array(
                'id'       => 'social_icon3',
                'type'     => 'select',
                'title'    => esc_html__('Social icon', 'narrative'), 
                'options'  => array(
                    '' => esc_html__('---', 'narrative'),
                    'fa fa-500px,none,500px' => esc_html__('500px', 'narrative'),
                    'fa fa-behance,social-icon-color-behance,Behance' => esc_html__('Behance', 'narrative'),
                    'fa fa-deviantart,social-icon-color-deviantart,Deviantart' => esc_html__('Deviantart', 'narrative'),
                    'fa fa-dribbble,social-icon-color-dribbble,Dribbble' => esc_html__('Dribbble', 'narrative'),
                    'fa fa-dropbox,social-icon-color-dropbox,Dropbox' => esc_html__('Dropbox', 'narrative'),
                    'fa fa-facebook,social-icon-color-facebook,Facebook' => esc_html__('Facebook', 'narrative'),
                    'fa fa-flickr,social-icon-color-flickr,Flickr' => esc_html__('Flickr', 'narrative'),
                    'fa fa-foursquare,social-icon-color-foursquare,Foursquare' => esc_html__('Foursquare', 'narrative'),
                    'fa fa-google,social-icon-color-google-plus,Google-Plus' => esc_html__('Google-Plus', 'narrative'),
                    'fa fa-instagram,social-icon-color-instagram,Instagram' => esc_html__('Instagram', 'narrative'),
                    'fa fa-line,social-icon-color-line,Line' => esc_html__('Line', 'narrative'),
                    'fa fa-linkedin,social-icon-color-linkedin,LinkedIn' => esc_html__('LinkedIn', 'narrative'),
                    'fa fa-pinterest,social-icon-color-pinterest,Pinterest' => esc_html__('Pinterest', 'narrative'),
                    'fa fa-quora,social-icon-color-quora,Quora' => esc_html__('Quora', 'narrative'),
                    'fa fa-skype,social-icon-color-skype,Skype' => esc_html__('Skype', 'narrative'),
                    'fa fa-snapchat-ghost,social-icon-color-snapchat,Snapchat' => esc_html__('Snapchat', 'narrative'),
                    'fa fa-soundcloud,social-icon-color-soundcloud,Soundcloud' => esc_html__('Soundcloud', 'narrative'),
                    'fa fa-spotify,social-icon-color-spotify,Spotify' => esc_html__('Spotify', 'narrative'),
                    'fa fa-telegram-plane,social-icon-color-telegram,Telegram' => esc_html__('Telegram', 'narrative'),
                    'fa fa-tumblr,social-icon-color-tumblr,Tumblr' => esc_html__('Tumblr', 'narrative'),
                    'fa fa-twitter,social-icon-color-twitter,Twitter' => esc_html__('Twitter', 'narrative'),
                    'fa fa-viber,social-icon-color-viber,Viber' => esc_html__('Viber', 'narrative'),
                    'fa fa-vimeo-square,social-icon-color-vimeo,Vimeo' => esc_html__('Vimeo', 'narrative'),
                    'fa fa-vine,social-icon-color-vine,Vine' => esc_html__('Vine', 'narrative'),
                    'fa fa-whatsapp,social-icon-color-whatsapp,WhatsApp' => esc_html__('WhatsApp', 'narrative'),
                    'fa fa-yelp,social-icon-color-yelp,Yelp' => esc_html__('Yelp', 'narrative'),
                    'fa fa-youtube,social-icon-color-youtube,YouYube' => esc_html__('YouYube', 'narrative'),
                ),
                'default'  => '',
            ),
            array(
                'id'       => 'social_link3',
                'type'     => 'text',
                'title'    => esc_html__('Link', 'narrative'),
            ),
            array(
                'id'       => 'sb4',
                'type'     => 'label',
                'title'    => esc_html__('Social button 4', 'narrative'),
            ),
            array(
                'id'       => 'social_icon4',
                'type'     => 'select',
                'title'    => esc_html__('Social icon', 'narrative'), 
                'options'  => array(
                    '' => esc_html__('---', 'narrative'),
                    'fa fa-500px,none,500px' => esc_html__('500px', 'narrative'),
                    'fa fa-behance,social-icon-color-behance,Behance' => esc_html__('Behance', 'narrative'),
                    'fa fa-deviantart,social-icon-color-deviantart,Deviantart' => esc_html__('Deviantart', 'narrative'),
                    'fa fa-dribbble,social-icon-color-dribbble,Dribbble' => esc_html__('Dribbble', 'narrative'),
                    'fa fa-dropbox,social-icon-color-dropbox,Dropbox' => esc_html__('Dropbox', 'narrative'),
                    'fa fa-facebook,social-icon-color-facebook,Facebook' => esc_html__('Facebook', 'narrative'),
                    'fa fa-flickr,social-icon-color-flickr,Flickr' => esc_html__('Flickr', 'narrative'),
                    'fa fa-foursquare,social-icon-color-foursquare,Foursquare' => esc_html__('Foursquare', 'narrative'),
                    'fa fa-google,social-icon-color-google-plus,Google-Plus' => esc_html__('Google-Plus', 'narrative'),
                    'fa fa-instagram,social-icon-color-instagram,Instagram' => esc_html__('Instagram', 'narrative'),
                    'fa fa-line,social-icon-color-line,Line' => esc_html__('Line', 'narrative'),
                    'fa fa-linkedin,social-icon-color-linkedin,LinkedIn' => esc_html__('LinkedIn', 'narrative'),
                    'fa fa-pinterest,social-icon-color-pinterest,Pinterest' => esc_html__('Pinterest', 'narrative'),
                    'fa fa-quora,social-icon-color-quora,Quora' => esc_html__('Quora', 'narrative'),
                    'fa fa-skype,social-icon-color-skype,Skype' => esc_html__('Skype', 'narrative'),
                    'fa fa-snapchat-ghost,social-icon-color-snapchat,Snapchat' => esc_html__('Snapchat', 'narrative'),
                    'fa fa-soundcloud,social-icon-color-soundcloud,Soundcloud' => esc_html__('Soundcloud', 'narrative'),
                    'fa fa-spotify,social-icon-color-spotify,Spotify' => esc_html__('Spotify', 'narrative'),
                    'fa fa-telegram-plane,social-icon-color-telegram,Telegram' => esc_html__('Telegram', 'narrative'),
                    'fa fa-tumblr,social-icon-color-tumblr,Tumblr' => esc_html__('Tumblr', 'narrative'),
                    'fa fa-twitter,social-icon-color-twitter,Twitter' => esc_html__('Twitter', 'narrative'),
                    'fa fa-viber,social-icon-color-viber,Viber' => esc_html__('Viber', 'narrative'),
                    'fa fa-vimeo-square,social-icon-color-vimeo,Vimeo' => esc_html__('Vimeo', 'narrative'),
                    'fa fa-vine,social-icon-color-vine,Vine' => esc_html__('Vine', 'narrative'),
                    'fa fa-whatsapp,social-icon-color-whatsapp,WhatsApp' => esc_html__('WhatsApp', 'narrative'),
                    'fa fa-yelp,social-icon-color-yelp,Yelp' => esc_html__('Yelp', 'narrative'),
                    'fa fa-youtube,social-icon-color-youtube,YouYube' => esc_html__('YouYube', 'narrative'),
                ),
                'default'  => '',
            ),
            array(
                'id'       => 'social_link4',
                'type'     => 'text',
                'title'    => esc_html__('Link', 'narrative'),
            ),
            array(
                'id'       => 'sb5',
                'type'     => 'label',
                'title'    => esc_html__('Social button 5', 'narrative'),
            ),
            array(
                'id'       => 'social_icon5',
                'type'     => 'select',
                'title'    => esc_html__('Social icon', 'narrative'), 
                'options'  => array(
                    '' => esc_html__('---', 'narrative'),
                    'fa fa-500px,none,500px' => esc_html__('500px', 'narrative'),
                    'fa fa-behance,social-icon-color-behance,Behance' => esc_html__('Behance', 'narrative'),
                    'fa fa-deviantart,social-icon-color-deviantart,Deviantart' => esc_html__('Deviantart', 'narrative'),
                    'fa fa-dribbble,social-icon-color-dribbble,Dribbble' => esc_html__('Dribbble', 'narrative'),
                    'fa fa-dropbox,social-icon-color-dropbox,Dropbox' => esc_html__('Dropbox', 'narrative'),
                    'fa fa-facebook,social-icon-color-facebook,Facebook' => esc_html__('Facebook', 'narrative'),
                    'fa fa-flickr,social-icon-color-flickr,Flickr' => esc_html__('Flickr', 'narrative'),
                    'fa fa-foursquare,social-icon-color-foursquare,Foursquare' => esc_html__('Foursquare', 'narrative'),
                    'fa fa-google,social-icon-color-google-plus,Google-Plus' => esc_html__('Google-Plus', 'narrative'),
                    'fa fa-instagram,social-icon-color-instagram,Instagram' => esc_html__('Instagram', 'narrative'),
                    'fa fa-line,social-icon-color-line,Line' => esc_html__('Line', 'narrative'),
                    'fa fa-linkedin,social-icon-color-linkedin,LinkedIn' => esc_html__('LinkedIn', 'narrative'),
                    'fa fa-pinterest,social-icon-color-pinterest,Pinterest' => esc_html__('Pinterest', 'narrative'),
                    'fa fa-quora,social-icon-color-quora,Quora' => esc_html__('Quora', 'narrative'),
                    'fa fa-skype,social-icon-color-skype,Skype' => esc_html__('Skype', 'narrative'),
                    'fa fa-snapchat-ghost,social-icon-color-snapchat,Snapchat' => esc_html__('Snapchat', 'narrative'),
                    'fa fa-soundcloud,social-icon-color-soundcloud,Soundcloud' => esc_html__('Soundcloud', 'narrative'),
                    'fa fa-spotify,social-icon-color-spotify,Spotify' => esc_html__('Spotify', 'narrative'),
                    'fa fa-telegram-plane,social-icon-color-telegram,Telegram' => esc_html__('Telegram', 'narrative'),
                    'fa fa-tumblr,social-icon-color-tumblr,Tumblr' => esc_html__('Tumblr', 'narrative'),
                    'fa fa-twitter,social-icon-color-twitter,Twitter' => esc_html__('Twitter', 'narrative'),
                    'fa fa-viber,social-icon-color-viber,Viber' => esc_html__('Viber', 'narrative'),
                    'fa fa-vimeo-square,social-icon-color-vimeo,Vimeo' => esc_html__('Vimeo', 'narrative'),
                    'fa fa-vine,social-icon-color-vine,Vine' => esc_html__('Vine', 'narrative'),
                    'fa fa-whatsapp,social-icon-color-whatsapp,WhatsApp' => esc_html__('WhatsApp', 'narrative'),
                    'fa fa-yelp,social-icon-color-yelp,Yelp' => esc_html__('Yelp', 'narrative'),
                    'fa fa-youtube,social-icon-color-youtube,YouYube' => esc_html__('YouYube', 'narrative'),
                ),
                'default'  => '',
            ),
            array(
                'id'       => 'social_link5',
                'type'     => 'text',
                'title'    => esc_html__('Link', 'narrative'),
            ),
            array(
                'id'       => 'sb6',
                'type'     => 'label',
                'title'    => esc_html__('Social button 6', 'narrative'),
            ),
            array(
                'id'       => 'social_icon6',
                'type'     => 'select',
                'title'    => esc_html__('Social icon', 'narrative'), 
                'options'  => array(
                    '' => esc_html__('---', 'narrative'),
                    'fa fa-500px,none,500px' => esc_html__('500px', 'narrative'),
                    'fa fa-behance,social-icon-color-behance,Behance' => esc_html__('Behance', 'narrative'),
                    'fa fa-deviantart,social-icon-color-deviantart,Deviantart' => esc_html__('Deviantart', 'narrative'),
                    'fa fa-dribbble,social-icon-color-dribbble,Dribbble' => esc_html__('Dribbble', 'narrative'),
                    'fa fa-dropbox,social-icon-color-dropbox,Dropbox' => esc_html__('Dropbox', 'narrative'),
                    'fa fa-facebook,social-icon-color-facebook,Facebook' => esc_html__('Facebook', 'narrative'),
                    'fa fa-flickr,social-icon-color-flickr,Flickr' => esc_html__('Flickr', 'narrative'),
                    'fa fa-foursquare,social-icon-color-foursquare,Foursquare' => esc_html__('Foursquare', 'narrative'),
                    'fa fa-google,social-icon-color-google-plus,Google-Plus' => esc_html__('Google-Plus', 'narrative'),
                    'fa fa-instagram,social-icon-color-instagram,Instagram' => esc_html__('Instagram', 'narrative'),
                    'fa fa-line,social-icon-color-line,Line' => esc_html__('Line', 'narrative'),
                    'fa fa-linkedin,social-icon-color-linkedin,LinkedIn' => esc_html__('LinkedIn', 'narrative'),
                    'fa fa-pinterest,social-icon-color-pinterest,Pinterest' => esc_html__('Pinterest', 'narrative'),
                    'fa fa-quora,social-icon-color-quora,Quora' => esc_html__('Quora', 'narrative'),
                    'fa fa-skype,social-icon-color-skype,Skype' => esc_html__('Skype', 'narrative'),
                    'fa fa-snapchat-ghost,social-icon-color-snapchat,Snapchat' => esc_html__('Snapchat', 'narrative'),
                    'fa fa-soundcloud,social-icon-color-soundcloud,Soundcloud' => esc_html__('Soundcloud', 'narrative'),
                    'fa fa-spotify,social-icon-color-spotify,Spotify' => esc_html__('Spotify', 'narrative'),
                    'fa fa-telegram-plane,social-icon-color-telegram,Telegram' => esc_html__('Telegram', 'narrative'),
                    'fa fa-tumblr,social-icon-color-tumblr,Tumblr' => esc_html__('Tumblr', 'narrative'),
                    'fa fa-twitter,social-icon-color-twitter,Twitter' => esc_html__('Twitter', 'narrative'),
                    'fa fa-viber,social-icon-color-viber,Viber' => esc_html__('Viber', 'narrative'),
                    'fa fa-vimeo-square,social-icon-color-vimeo,Vimeo' => esc_html__('Vimeo', 'narrative'),
                    'fa fa-vine,social-icon-color-vine,Vine' => esc_html__('Vine', 'narrative'),
                    'fa fa-whatsapp,social-icon-color-whatsapp,WhatsApp' => esc_html__('WhatsApp', 'narrative'),
                    'fa fa-yelp,social-icon-color-yelp,Yelp' => esc_html__('Yelp', 'narrative'),
                    'fa fa-youtube,social-icon-color-youtube,YouYube' => esc_html__('YouYube', 'narrative'),
                ),
                'default'  => '',
            ),
            array(
                'id'       => 'social_link6',
                'type'     => 'text',
                'title'    => esc_html__('Link', 'narrative'),
            ),
            array(
                'id'       => 'sb7',
                'type'     => 'label',
                'title'    => esc_html__('Social button 7', 'narrative'),
            ),
            array(
                'id'       => 'social_icon7',
                'type'     => 'select',
                'title'    => esc_html__('Social icon', 'narrative'), 
                'options'  => array(
                    '' => esc_html__('---', 'narrative'),
                    'fa fa-500px,none,500px' => esc_html__('500px', 'narrative'),
                    'fa fa-behance,social-icon-color-behance,Behance' => esc_html__('Behance', 'narrative'),
                    'fa fa-deviantart,social-icon-color-deviantart,Deviantart' => esc_html__('Deviantart', 'narrative'),
                    'fa fa-dribbble,social-icon-color-dribbble,Dribbble' => esc_html__('Dribbble', 'narrative'),
                    'fa fa-dropbox,social-icon-color-dropbox,Dropbox' => esc_html__('Dropbox', 'narrative'),
                    'fa fa-facebook,social-icon-color-facebook,Facebook' => esc_html__('Facebook', 'narrative'),
                    'fa fa-flickr,social-icon-color-flickr,Flickr' => esc_html__('Flickr', 'narrative'),
                    'fa fa-foursquare,social-icon-color-foursquare,Foursquare' => esc_html__('Foursquare', 'narrative'),
                    'fa fa-google,social-icon-color-google-plus,Google-Plus' => esc_html__('Google-Plus', 'narrative'),
                    'fa fa-instagram,social-icon-color-instagram,Instagram' => esc_html__('Instagram', 'narrative'),
                    'fa fa-line,social-icon-color-line,Line' => esc_html__('Line', 'narrative'),
                    'fa fa-linkedin,social-icon-color-linkedin,LinkedIn' => esc_html__('LinkedIn', 'narrative'),
                    'fa fa-pinterest,social-icon-color-pinterest,Pinterest' => esc_html__('Pinterest', 'narrative'),
                    'fa fa-quora,social-icon-color-quora,Quora' => esc_html__('Quora', 'narrative'),
                    'fa fa-skype,social-icon-color-skype,Skype' => esc_html__('Skype', 'narrative'),
                    'fa fa-snapchat-ghost,social-icon-color-snapchat,Snapchat' => esc_html__('Snapchat', 'narrative'),
                    'fa fa-soundcloud,social-icon-color-soundcloud,Soundcloud' => esc_html__('Soundcloud', 'narrative'),
                    'fa fa-spotify,social-icon-color-spotify,Spotify' => esc_html__('Spotify', 'narrative'),
                    'fa fa-telegram-plane,social-icon-color-telegram,Telegram' => esc_html__('Telegram', 'narrative'),
                    'fa fa-tumblr,social-icon-color-tumblr,Tumblr' => esc_html__('Tumblr', 'narrative'),
                    'fa fa-twitter,social-icon-color-twitter,Twitter' => esc_html__('Twitter', 'narrative'),
                    'fa fa-viber,social-icon-color-viber,Viber' => esc_html__('Viber', 'narrative'),
                    'fa fa-vimeo-square,social-icon-color-vimeo,Vimeo' => esc_html__('Vimeo', 'narrative'),
                    'fa fa-vine,social-icon-color-vine,Vine' => esc_html__('Vine', 'narrative'),
                    'fa fa-whatsapp,social-icon-color-whatsapp,WhatsApp' => esc_html__('WhatsApp', 'narrative'),
                    'fa fa-yelp,social-icon-color-yelp,Yelp' => esc_html__('Yelp', 'narrative'),
                    'fa fa-youtube,social-icon-color-youtube,YouYube' => esc_html__('YouYube', 'narrative'),
                ),
                'default'  => '',
            ),
            array(
                'id'       => 'social_link7',
                'type'     => 'text',
                'title'    => esc_html__('Link', 'narrative'),
            ),
        )
    ) );

    Redux::setSection( $opt_name, array(
        'title'            => esc_html__( 'Footer', 'narrative' ),
        'id'               => 'footer',
        'customizer_width' => '400px',
        'icon'             => 'fa fa-th-list',
        'fields'     => array(
            array(
                'id'       => 'footer',
                'type'     => 'select',
                'title'    => esc_html__('Footer', 'narrative'), 
                'options'  => array(
                    'show' => esc_html__('Show', 'narrative'),
                    'hide' => esc_html__('Hide', 'narrative'),
                ),
                'default'  => 'show',
            ),
            array(
                'id'       => 'footer_bg_color',
                'type'     => 'color',
                'title'    => esc_html__('Footer Background Color', 'narrative'),
                'validate' => 'color',
                'transparent' => false,
                'output'      => array('background-color' => '.site-footer'),
            ),
            array(
                'id'       => 'footer_text_color',
                'type'     => 'color',
                'title'    => esc_html__('Footer Text Color', 'narrative'),
                'validate' => 'color',
                'transparent' => false,
                'output'      => array('color' => '.site-footer'),
            ),
            array(
                'id'       => 'footer_col_1',
                'type'     => 'select',
                'title'    => esc_html__('Footer col 1', 'narrative'), 
                'options'  => array(
                    'hide' => 'Hide',
                    '1' => 'Col 1',
                    '2' => 'Col 2',
                    '3' => 'Col 3',
                    '4' => 'Col 4',
                    '5' => 'Col 5',
                    '6' => 'Col 6',
                    '7' => 'Col 7',
                    '8' => 'Col 8',
                    '9' => 'Col 9',
                    '10' => 'Col 10',
                    '11' => 'Col 11',
                    '12' => 'Col 12',
                ),
                'default'  => '4',
            ),
            array(
                'id'       => 'footer_col_2',
                'type'     => 'select',
                'title'    => esc_html__('Footer col 2', 'narrative'), 
                'options'  => array(
                    'hide' => 'Hide',
                    '1' => 'Col 1',
                    '2' => 'Col 2',
                    '3' => 'Col 3',
                    '4' => 'Col 4',
                    '5' => 'Col 5',
                    '6' => 'Col 6',
                    '7' => 'Col 7',
                    '8' => 'Col 8',
                    '9' => 'Col 9',
                    '10' => 'Col 10',
                    '11' => 'Col 11',
                    '12' => 'Col 12',
                ),
                'default'  => '4',
            ),
            array(
                'id'       => 'footer_col_3',
                'type'     => 'select',
                'title'    => esc_html__('Footer col 3', 'narrative'), 
                'options'  => array(
                    'hide' => 'Hide',
                    '1' => 'Col 1',
                    '2' => 'Col 2',
                    '3' => 'Col 3',
                    '4' => 'Col 4',
                    '5' => 'Col 5',
                    '6' => 'Col 6',
                    '7' => 'Col 7',
                    '8' => 'Col 8',
                    '9' => 'Col 9',
                    '10' => 'Col 10',
                    '11' => 'Col 11',
                    '12' => 'Col 12',
                ),
                'default'  => '4',
            ),
            array(
                'id'       => 'footer_col_4',
                'type'     => 'select',
                'title'    => esc_html__('Footer col 4', 'narrative'), 
                'options'  => array(
                    'hide' => 'Hide',
                    '1' => 'Col 1',
                    '2' => 'Col 2',
                    '3' => 'Col 3',
                    '4' => 'Col 4',
                    '5' => 'Col 5',
                    '6' => 'Col 6',
                    '7' => 'Col 7',
                    '8' => 'Col 8',
                    '9' => 'Col 9',
                    '10' => 'Col 10',
                    '11' => 'Col 11',
                    '12' => 'Col 12',
                ),
                'default'  => 'hide',
            ),
        )
    ) );

    Redux::setSection( $opt_name, array(
        'title'            => esc_html__( '404 Page', 'narrative' ),
        'id'               => '404_page',
        'customizer_width' => '400px',
        'icon'             => 'fa fa-exclamation-circle',
        'fields'     => array(
            array( 
                'id'       => '404_bg',
                'type'     => 'background',
                'title'    => esc_html__('Background image', 'narrative'),
                'background-attachment' => false,
                'background-position' => false,
                'background-repeat' => false,
                'background-origin' => false,
                'background-color' => false,
                'background-size' => false,
                'background-clip' => false,
                'preview_media' => true,
                'preview' => false,
            ),
            array(
                'id'       => '404_page_color',
                'type'     => 'color',
                'title'    => esc_html__('Text color', 'narrative'),
                'validate' => 'color',
                'transparent' => false,
                'output'      => array('color' => '.banner-404'),
            ),
            array(
                'id'       => '404_page_heading_color',
                'type'     => 'color',
                'title'    => esc_html__('Heading color', 'narrative'),
                'validate' => 'color',
                'transparent' => false,
                'output'      => array('color' => '.banner-404 .con-404 .h'),
            ),
            array(
                'id'       => '404_page_heading',
                'type'     => 'textarea',
                'title'    => esc_html__('Heading', 'narrative'),
                'default'  => __('<span>404</span><br>PAGE NOT FOUND', 'narrative'),
            ),
            array(
                'id'       => '404_page_desc',
                'type'     => 'textarea',
                'title'    => esc_html__('Desc', 'narrative'),
                'default'  => esc_html__('The page you were looking for could not be found.', 'narrative'),
            ),
        )
    ) );

    Redux::setSection( $opt_name, array(
        'title'            => esc_html__( 'Coming soon page', 'narrative' ),
        'id'               => 'coming_soon',
        'customizer_width' => '400px',
        'icon'             => 'fa fa-clock-o',
        'fields'     => array(
            array( 
                'id'       => 'coming_soon_bg',
                'type'     => 'background',
                'title'    => esc_html__('Background image', 'narrative'),
                'background-attachment' => false,
                'background-position' => false,
                'background-repeat' => false,
                'background-origin' => false,
                'background-color' => false,
                'background-size' => false,
                'background-clip' => false,
                'preview_media' => true,
                'preview' => false,
            ),
            array(
                'id'       => 'coming_soon_color',
                'type'     => 'color',
                'title'    => esc_html__('Text color', 'narrative'),
                'validate' => 'color',
                'transparent' => false,
                'output'      => array('color' => '.banner-coming-soon'),
            ),
            array(
                'id'       => 'coming_soon_heading_color',
                'type'     => 'color',
                'title'    => esc_html__('Heading color', 'narrative'),
                'validate' => 'color',
                'transparent' => false,
                'output'      => array('color' => '.banner-coming-soon .con-coming-soon .h'),
            ),
            array(
                'id'       => 'coming_soon_heading',
                'type'     => 'textarea',
                'title'    => esc_html__('Heading', 'narrative'),
                'default'  => esc_html__('We`re getting ready to launch', 'narrative'),
            ),
            array(
                'id'       => 'coming_soon_subscribe_desc',
                'type'     => 'textarea',
                'title'    => esc_html__('Subscribe form desc', 'narrative'),
                'default'  => esc_html__('Subscribe and get the latest news', 'narrative'),
            ),
            array(
                'id'       => 'coming_soon_subscribe_code',
                'type'     => 'text',
                'title'    => esc_html__('Subscribe form code', 'narrative'),
            ),
        )
    ) );

    Redux::setSection( $opt_name, array(
        'title'            => esc_html__( 'Project page', 'narrative' ),
        'id'               => 'project_page',
        'customizer_width' => '400px',
        'icon'             => 'fa fa-file-text',
        'fields'     => array(
            array(
                'id'       => 'project_style',
                'type'     => 'select',
                'title'    => esc_html__('Style project page', 'narrative'), 
                'options'  => array(
                    'simple' => esc_html__('Simple', 'narrative'),
                    'slider' => esc_html__('Slider', 'narrative'),
                    'masonry' => esc_html__('Masonry', 'narrative'),
                    'horizontal' => esc_html__('Horizontal', 'narrative'),
                ),
                'default'  => 'simple',
            ),
            array(
                'id'       => 'project-details',
                'type'     => 'select',
                'title'    => esc_html__('Project details', 'narrative'), 
                'options'  => array(
                    'yes' => esc_html__('Show', 'narrative'),
                    'no' => esc_html__('Hide', 'narrative'),
                ),
                'default'  => 'yes',
            ),
            array(
                'id'       => 'download-link',
                'type'     => 'select',
                'title'    => esc_html__('Download link on popup', 'narrative'), 
                'options'  => array(
                    'yes' => esc_html__('Show', 'narrative'),
                    'no' => esc_html__('Hide', 'narrative'),
                ),
                'default'  => 'yes',
            ),
        )
    ) );

    Redux::setSection( $opt_name, array(
        'title'            => esc_html__( 'Blog post', 'narrative' ),
        'id'               => 'blog_post',
        'customizer_width' => '400px',
        'icon'             => 'fa fa-wordpress',
        'fields'     => array(
            array(
                'id'       => 'blog_feature_image',
                'type'     => 'select',
                'title'    => esc_html__('Blog feature image', 'narrative'), 
                'options'  => array(
                    'hide' => esc_html__('Hide', 'narrative'),
                    'show' => esc_html__('Show', 'narrative'),
                ),
                'default'  => 'show',
            ),
            array(
                'id'       => 'blog_date',
                'type'     => 'select',
                'title'    => esc_html__('Show date', 'narrative'), 
                'options'  => array(
                    'show' => esc_html__('Show', 'narrative'),
                    'hide' => esc_html__('Hide', 'narrative'),
                ),
                'default'  => 'show',
            ),
            array(
                'id'       => 'blog_like',
                'type'     => 'select',
                'title'    => esc_html__('Show like', 'narrative'), 
                'options'  => array(
                    'show' => esc_html__('Show', 'narrative'),
                    'hide' => esc_html__('Hide', 'narrative'),
                ),
                'default'  => 'show',
            ),
            array(
                'id'       => 'blog_views',
                'type'     => 'select',
                'title'    => esc_html__('Show views count', 'narrative'), 
                'options'  => array(
                    'show' => esc_html__('Show', 'narrative'),
                    'hide' => esc_html__('Hide', 'narrative'),
                ),
                'default'  => 'show',
            ),
            array(
                'id'       => 'blog_comment_count',
                'type'     => 'select',
                'title'    => esc_html__('Show comment count', 'narrative'), 
                'options'  => array(
                    'show' => esc_html__('Show', 'narrative'),
                    'hide' => esc_html__('Hide', 'narrative'),
                ),
                'default'  => 'show',
            ),
        )
    ) );

    Redux::setSection( $opt_name, array(
        'title'            => esc_html__( 'Google Maps API', 'narrative' ),
        'id'               => 'google_maps_api',
        'customizer_width' => '400px',
        'icon'             => 'fa fa-map-pin',
        'fields'     => array(
            array(
                'id'       => 'google_maps_api_key',
                'type'     => 'text',
                'title'    => esc_html__('Google Map API Key', 'narrative'), 
                'description' => __('Create an application in <a href="https://console.developers.google.com/flows/enableapi?apiid=places_backend,maps_backend,geocoding_backend,directions_backend,distance_matrix_backend,elevation_backend&keyType=CLIENT_SIDE&reusekey=true" target="_blank">Google Console</a> and add the Key here.', 'narrative'),
            ),
        )
    ) );

    Redux::setSection( $opt_name, array(
        'title'            => esc_html__( 'Site info', 'narrative' ),
        'id'               => 'site_info',
        'customizer_width' => '400px',
        'icon'             => 'el el-info-circle',
        'fields'     => array(
            array(
                'id'       => 'opt-raw_info_4',
                'type'     => 'raw',
                'title'    => false,
                'content'  => $info_html,
            ),
        )
    ) );

